# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import payment_link_wizard
from . import payment_onboarding_wizard
